pub struct InitializePositionPda {
pub payer: Pubkey,
pub base: Pubkey,
pub position: Pubkey,
pub lb_pair: Pubkey,
pub owner: Pubkey,
pub system_program: Pubkey,
pub rent: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for InitializePositionPda.
Fields
payer: Pubkeybase: Pubkeyposition: Pubkeylb_pair: Pubkeyowner: Pubkeyowner
system_program: Pubkeyrent: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for InitializePositionPdawhere
Pubkey: BorshSerialize,
impl BorshSerialize for InitializePositionPdawhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for InitializePositionPda
impl ToAccountMetas for InitializePositionPda
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for InitializePositionPda
impl RefUnwindSafe for InitializePositionPda
impl Send for InitializePositionPda
impl Sync for InitializePositionPda
impl Unpin for InitializePositionPda
impl UnwindSafe for InitializePositionPda