pub struct InitializeReward {
pub lb_pair: Pubkey,
pub reward_vault: Pubkey,
pub reward_mint: Pubkey,
pub admin: Pubkey,
pub token_program: Pubkey,
pub system_program: Pubkey,
pub rent: Pubkey,
pub event_authority: Pubkey,
pub program: Pubkey,
}Expand description
Generated client accounts for InitializeReward.
Fields
lb_pair: Pubkeyreward_vault: Pubkeyreward_mint: Pubkeyadmin: Pubkeytoken_program: Pubkeysystem_program: Pubkeyrent: Pubkeyprogram: PubkeyTrait Implementations
Sourceimpl BorshSerialize for InitializeRewardwhere
Pubkey: BorshSerialize,
impl BorshSerialize for InitializeRewardwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for InitializeReward
impl ToAccountMetas for InitializeReward
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for InitializeReward
impl RefUnwindSafe for InitializeReward
impl Send for InitializeReward
impl Sync for InitializeReward
impl Unpin for InitializeReward
impl UnwindSafe for InitializeReward