DynamicOracle

Struct DynamicOracle 

pub struct DynamicOracle<'a> {
    pub metadata: RefMut<'a, Oracle>,
    pub observations: RefMut<'a, [Observation]>,
}
An oracle struct loaded with dynamic sized data type

Fields

metadata: RefMut<'a, Oracle>observations: RefMut<'a, [Observation]>

Implementations

Source

impl<'a> DynamicOracle<'a>

pub fn new( metadata: RefMut<'a, Oracle>, observations: RefMut<'a, [Observation]>, ) -> DynamicOracle<'a>

pub fn get_latest_sample_mut<'dyo>( &'dyo mut self, ) -> Option<&'dyo mut Observation>

Return the latest observation sample

pub fn get_latest_sample<'dyo>(&'dyo self) -> Option<&'dyo Observation>

pub fn get_earliest_sample<'dyo>(&'dyo self) -> Option<&'dyo Observation>

Return the earliest observation sample

pub fn update(&mut self, active_id: i32, current_timestamp: i64) -> Result<()>

Update existing observation sample / create a new observation sample based on sample lifetime expiration